<?php
namespace pjp\core\errorhandling;

use Exception;
use ErrorException;

/**
 * Defines the error and exception handlers and provides hooks for dispatching the exceptions
 * to custom behaviour. Please note that not all PHP errors can be trapped through this mechanism.
 */
class ErrorHandler {
	private static $actions = array();

	/**
	 * Register a callback function to be called when an exception/error is trapped.
	 */	
	public static function addHandlerAction($action) {
		self::$actions[$action] = $action;
	}

	/**
	 * Unregister a callback function from being called when an exception/error is trapped.
	 */	
	public static function removeHandlerAction($action) {
		unset(self::$actions[$action]);
	}

	/**
	 * Traps errors and rethrows as ErrorException.
	 */	
	public static function handleError($errno, $errstr, $errfile, $errline) {
		self::handleException( new ErrorException($errstr, 0, $errno, $errfile, $errline) );
	}

	/**
	 * Traps exceptions and passes them to handler callbacks.
	 */	
	public static function handleException(Exception $exception) {
		foreach(self::$actions as $doaction)
			call_user_func($doaction, $exception);
	}

}

?>
