<?php
namespace pjp\core\pluginmanagement;

/**
 * Provides a template method for loading plugins. Implementation details
 * are to be dealt with by subclasses, who will implement the abstract hook methods.
 */
abstract class AbstractPluginLoader {

	protected function __construct() {
	}

	/**
	 * Load plugin specified by ID. Throws exceptions on failure.
	 */
	final public function loadPlugin($pluginid) {
		$plugin = '';

		if ( $this->pluginIsLoaded($pluginid) )
			return;

		if (! $this->pluginExists($pluginid) )
			throw PluginLoaderException::doesNotExist($pluginid);

		try {
			$plugin = $this->buildPlugin($pluginid);
			$this->loadDependantPlugins($plugin);
			$this->registerPlugin($plugin);
			$this->activatePlugin($plugin);
		}
		catch(Exception $e) {
			throw PluginLoaderException::loadingFailed($pluginid, $e);
		}
	}

	protected abstract function pluginIsLoaded($pluginid);

	protected abstract function pluginExists($pluginid);
	
	protected abstract function buildPlugin($pluginid);

	protected abstract function loadDependantPlugins(Plugin $plugin);

	protected abstract function registerPlugin(Plugin $plugin);

	protected abstract function activatePlugin(Plugin $plugin);

}

?>
