<?php
namespace pjp\core\pluginmanagement;

use pjp\core\interfaces\Builder;

/**
 * Reads and processes the plugin manifest. Implementing the Builder pattern,
 * this class is responsible for ultimately producing a Plugin object.
 */
class PluginBuilder implements Builder {
	const NAME = 'name';
	const ID = 'id';
	const VERSION = 'version';
	const ACTIVATOR = 'activator';
	const DEPENDANCIES = 'dependancies';

	private $plugindetails;

	public function __construct() {
		$this->plugindetails = array();

		$this->plugindetails[self::NAME] = '';
		$this->plugindetails[self::ID] = '';
		$this->plugindetails[self::VERSION] = '';
		$this->plugindetails[self::ACTIVATOR] = '';
		$this->plugindetails[self::DEPENDANCIES] = array();
	}

	public function processManifestFromString($manifeststring) {
		//Tokenize details
		foreach(explode(';', $manifeststring) as $detail) {
			if(! $detail) continue;

			//Split the detail into a key:value pair
			list($key, $value) = explode(':', $detail);
			$key = trim($key);
			$value = trim($value);

			//if dependancies, convert to array
			if($key == self::DEPENDANCIES) {
				$dependancies = explode(',', $value);
				//trim surrounding whitespace
				array_walk( $dependancies, function(& $value, $index){ $value = trim($value); } );

				$value = $dependancies;
			}

			$this->plugindetails[$key] = $value;
		}

		if(! $this->hasAllRequiredDetails() )
			throw new PluginLoaderException('Missing required manifest details');
	}

	/**
	 * Get the built plugin.
	 */
	public function getProduct() {
		$plugin = Plugin::createPlugin(
			$this->plugindetails[self::NAME],
			$this->plugindetails[self::ID],
			$this->plugindetails[self::VERSION],
			$this->plugindetails[self::ACTIVATOR],
			$this->plugindetails[self::DEPENDANCIES]
		);
		return $plugin;
	}

	//helper method for determnining if all critical plugin details have been supplied.
	private function hasAllRequiredDetails() {
		return !($this->plugindetails[self::NAME] == '' || $this->plugindetails[self::ID] == '' || $this->plugindetails[self::VERSION] == '');
	}

}

?>