<?php
namespace pjp\core\pluginmanagement;

/**
 * Responsible for storing plugins' descriptive details in runtime.
 * It has been implemented as a singleton.
 */
final class PluginLibrary {
	private static $instance;

	private $library;

	private function __construct() {
		$this->library = array();
	}

	/**
	 * Get the library.
	 */
	public static function getLibrary() {
		if (! isset(self::$instance) )
			self::$instance = new self();

		return self::$instance;
	}

	/**
	 * Register plugin in the library.
	 */
	public function registerPlugin($plugin) {
		$this->library[$plugin->id] = $plugin;
	}

	/**
	 * Determine by ID if a plugin is registered.
	 */
	public function pluginIdIsRegistered($pluginid) {
		return array_key_exists($pluginid, $this->library);
	}

	/**
	 * Retreive a plugin from the library by ID.
	 */
	public function getPluginById($pluginid) {
		return $this->library[$pluginid];
	}

	/**
	 * Get a list of IDs of registered plugins.
	 */
	public function getRegisteredPluginIds() {
		return array_keys($this->library);
	}

}

?>