<?php
namespace pjp\core\pluginmanagement;

use Exception;

/**
 * To be thrown when there is a pluginloader-related exception.
 * Several factory methods have been provided to ensure standardized
 * error messages.
 */
class PluginLoaderException extends Exception {
	const PLUGIN_DOES_NOT_EXIST = "Plugin '%s' does not exist";
	const INVALID_PLUGIN_MANIFEST = "Plugin '%s' has an invalid manifest";
	const PLUGIN_LOADING_FAILED = "Unable to load Plugin %s";
	const INVALID_PLUGIN_ACTIVATOR = "Plugin %s has an invalid activator";

	public function __construct($message, $previous = null) {
		parent::__construct($message, 0, $previous);
	}

	public static function doesNotExist($pluginid, $previous = null) {
		return self::createException(self::PLUGIN_DOES_NOT_EXIST, $pluginid, $previous);
	}

	public static function invalidManifest($pluginid, $previous = null) {
		return self::createException(self::INVALID_PLUGIN_MANIFEST, $pluginid, $previous);
	}

	public static function loadingFailed($pluginid, $previous = null) {
		return self::createException(self::PLUGIN_LOADING_FAILED, $pluginid, $previous);
	}

	public static function invalidActivator($pluginid, $previous = null) {
		return self::createException(self::INVALID_PLUGIN_ACTIVATOR, $pluginid, $previous);
	}

	private static function createException($exceptionstring, $pluginid, $previous) {
		$message = sprintf($exceptionstring, $pluginid);
		return new self($message, $previous);
	}

}

?>