<?php
namespace pjp\core\xmlprocessing;

/**
 * XML parser class that wraps the PHP XML parser.
 * See http://www.php.net/manual/en/book.xml.php for further details.
*/
class XMLParser {

	private $parser;
	private $parsehandler;

	public function __construct(XMLParseHandler $parsehandler) {
		$this->parser = xml_parser_create_ns();
		$this->parsehandler = $parsehandler;

		xml_set_object($this->parser, $this);

		xml_set_character_data_handler($this->parser, "characterDataHandler");
		xml_set_default_handler($this->parser, "defaultHandler");
		xml_set_element_handler($this->parser, "startElementHandler", "endElementHandler");
		xml_set_start_namespace_decl_handler($this->parser, "startNamespaceHandler");
		xml_set_end_namespace_decl_handler($this->parser, "endNamespaceHandler");
		xml_set_external_entity_ref_handler($this->parser, "externalEntityRefHandler");
		xml_set_unparsed_entity_decl_handler($this->parser, "unparsedEntityHandler");
		xml_set_notation_decl_handler($this->parser, "notationHandler");
		xml_set_processing_instruction_handler($this->parser, "processingInstructionHandler");
	}

	//Converts a string with ISO-8859-1 characters encoded with UTF-8 to single-byte ISO-8859-1
	public static function utf8Decode($data) {
		return utf8_decode($data);
	}

	//Encodes an ISO-8859-1 string to UTF-8
	public static function utf8Encode($data) {
		return utf8_encode($data);
	}

	//Get XML parser error code
	public function getErrorCode() {
		return xml_get_error_code($this->parser);
	}

	//Get XML parser error string
	public function getErrorString($code) {
		return xml_error_string($code);
	}

	//Get XML parser error message
	public function getErrorMessage() {
		return $this->getErrorString( $this->getErrorCode() );
	}

	//Get current byte index for an XML parser
	public function getCurrentByteIndex() {
		return xml_get_current_byte_index($this->parser);
	}

	//Get current column number for an XML parser 
	public function getCurrentColumnNumber() {
		return xml_get_current_column_number($this->parser);
	}

	//Get current line number for an XML parser
	public function getCurrentLineNumber() {
		return xml_get_current_line_number($this->parser);
	}

	//Start parsing an XML document
	public function parseData($data, $isfinal = false){
		return xml_parse($this->parser, $data, $isfinal);
	}

	//Get options from an XML parser
	public function getOption($option) {
		return xml_parser_get_option($this->parser, $option);
	}

	//Set options in an XML parser
	public function setOption($option, $value) {
		return xml_parser_set_option($this->parser, $option, $value);
	}

	protected function characterDataHandler($parser, $data) {
		$this->parsehandler->characterDataHandler($this, $data);
	}

	protected function defaultHandler($parser, $data) {
		$this->parsehandler->defaultHandler($this, $data) ;
	}

	protected function startElementHandler($parser, $elementname, $attribs) {
		$this->parsehandler->startElementHandler($this, $elementname, $attribs);
	}

	protected function endElementHandler($parser, $elementname) {
		$this->parsehandler->endElementHandler($this, $elementname);
	}

	protected function startNamespaceHandler($parser, $prefix, $uri) {
		return $this->parsehandler->startNamespaceHandler($this, $prefix, $uri);
	}

	protected function endNamespaceHandler($parser, $prefix, $uri) {
		return $this->parsehandler->endNamespaceHandler($this, $prefix, $uri);
	}

	protected function externalEntityRefHandler($parser, $openentitynames, $base, $systemid, $publicid) {
		$this->parsehandler->externalEntityRefHandler($this, $openentitynames, $base, $systemid, $publicid);
	}

	protected function unparsedEntityHandler($parser, $entityname, $base, $systemid, $publicid, $notationname) {
		$this->parsehandler->unparsedEntityHandler($this, $entityname, $base, $systemid, $publicid, $notationname);
	}

	protected function notationHandler($parser, $notationname, $base, $systemid, $publicid) {
		$this->parsehandler->notationHandler($this, $notationname, $base, $systemid, $publicid);
	}

	protected function processingInstructionHandler($parser, $target, $data) {
		$this->parsehandler->processingInstructionHandler($this, $target, $data);
	}

}

?>
