<?php
namespace pjp\mvc\controller;

use pjp\mvc\dispatch\Request;

/**
 * Abstract class defining the controller skeleton through template pattern.
 * First, the request processed. Secondly, any necessary post-processing is applied.
 * Lastly, the response is rendered/displayed. Details are left to the implementation.
 */
abstract class RequestController {
	private $request;

	public function __construct() {
	}

	public function handleRequest(Request $request) {
		$this->request = $request;

		$this->respondToRequest();
		$this->postProcessResponse();
		$this->displayResponse();
	}

	public function getRequest() {
		return $this->request;
	}

	abstract protected function respondToRequest();
	abstract protected function postProcessResponse();
	abstract protected function displayResponse();

}

?>