<?php
namespace pjp\mvc\dispatch;

/**
 * Abstract class defining the main dispatcher skeleton through template pattern.
 * First, the request is filtered. This is where you should make any modifications
 * to the parameters and/or defer the request if another action must be run first (login page, etc).
 * Then, the request is dispatched to the appropriate request handler.
 * Details are left to the implementation. Use of the MVC components is recommended.
 */
abstract class FrontController {
	private $dispatchmap;
	private $request;

	public function __construct(DispatchMap $dispatchmap) {
		$this->dispatchmap = $dispatchmap;
		$this->request = Request::getRequest();
	}

	public function handleRequest() {
		$this->request = $this->filterRequest($this->request, $this->dispatchmap);
		$this->dispatchRequest($this->dispatchmap, $this->request);
	}

	abstract protected function filterRequest(Request $request, DispatchMap $dispatchmap);
	abstract protected function dispatchRequest(DispatchMap $dispatchmap, Request $request);

}

?>