<?php
namespace pjp\runtime;

use pjp\core\pluginmanagement\PluginLibrary;
use pjp\core\tools\PathBuilder;

/**
* Utility for providing information about plugins in runtime. Backed by the plugin library.
*/
class PluginInfo {

	/**
	 * Returns string containing information on plugin specified by id.
	 * Returns false on failure.
	 */
	public static function getPluginDetailsAsString($pluginid) {
		$pluginlibrary = PluginLibrary::GetLibrary();
		$description = false;

		if ( $pluginlibrary->pluginIdIsRegistered($pluginid) ) {
			$plugin = $pluginlibrary->getPlugin($pluginid);
			$description = sprintf('%s (%s %.2f)', $plugin->name, $plugin->id, $plugin->version);
		}

		return $description;
	}

	/**
	 * Returns a fully qualified path to the plugin id's respective physical plugin location,
	 * or false on failure.
	 */
	public static function getPluginPath($pluginid) {
		$platformpluginpath = PathBuilder::buildPlatformPath($pluginid);
		$applicationpluginpath = PathBuilder::buildApplicationPath($pluginid);

		if( is_dir($platformpluginpath) )
			return $platformpluginpath;
		elseif( is_dir($applicationpluginpath) )
			return $applicationpluginpath;
		else
			return false;
	}

	/**
	 * Returns an array containing all ids of available plugins.
	 */
	public static function listAvailablePluginsById() {
		$platformplugins = scandir(PJP_PLATFORM_PATH);
		$applicationplugins = scandir(PJP_APPLICATION_PATH);

		return array_diff( array_merge($platformplugins, $applicationplugins), array('.', '..') );
	}

}

?>